Learn R Programming

cleangeo (version 0.2-3)

cleangeo: Clean Geometries from Spatial Objects

Description

cleangeo provides a set of utility tools to inspect spatial objects, facilitate handling and reporting of topology errors and geometry validity issues. Finally, it provides a geometry cleaner that will fix all geometry problems, and eliminate (at least reduce) the likelihood of having issues when doing spatial data processing.

Arguments

Details

Package: cleangeo
Type: Package
Version: 0.2-3
Date: 2019-12-04
License: GPL(>=2.0)
LazyLoad: yes